package com.ti.mobpo.ui

import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.ti.mobpo.data.PokemonDetails
import com.ti.mobpo.network.PokeApi
import com.ti.mobpo.network.PokeApiService
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.launch
import retrofit2.Retrofit
import retrofit2.converter.gson.GsonConverterFactory
import java.io.IOException



class PokeSearchViewModel : ViewModel() {
    private val service = PokeApi.retrofitService;

    private val _pokemonDetails = MutableStateFlow<List<PokemonDetails>?>(null)
    val pokemonDetails: StateFlow<List<PokemonDetails>?> = _pokemonDetails.asStateFlow()

    fun search(query: String) {
        viewModelScope.launch {
            try {
                val response = service.getPokemon()
                val filteredList = response.results.filter { it.name.contains(query, ignoreCase = true) }
                val detailsList = mutableListOf<PokemonDetails>()
                for (pokemonSpecies in filteredList) {
                    val details = service.getPokemonDetails(extractPokemonId(pokemonSpecies.url))
                    detailsList.add(details)
                }
                _pokemonDetails.value = detailsList
            } catch (e: IOException) {
                /* Handle error */
            }
        }
    }

    private fun extractPokemonId(url: String): Int {
        val parts = url.split("/")
        return parts[parts.size - 2].toInt()
    }
}
